searchData={"items":[{"type":"module","title":"HttpCookie","doc":"HTTP Cookie struct with parsing and related logic.\n\nImplemented according to [RFC6265](https://datatracker.ietf.org/doc/html/rfc6265)","ref":"HttpCookie.html"},{"type":"function","title":"HttpCookie.expired?/2","doc":"Checks if the cookie has expired.\n\nUses the current time if no time is provided.","ref":"HttpCookie.html#expired?/2"},{"type":"function","title":"HttpCookie.from_cookie_string/3","doc":"Creates an HttpCookie from a `Set-Cookie` header value.","ref":"HttpCookie.html#from_cookie_string/3"},{"type":"function","title":"Options - HttpCookie.from_cookie_string/3","doc":"- `:max_cookie_size` - maximum size of cookie string in bytes, positive integer or :infinity, default: 8_192\n- `:reject_public_suffixes` - controls whether to reject public suffixes to guard against \"supercookies\", defaults to true","ref":"HttpCookie.html#from_cookie_string/3-options"},{"type":"function","title":"HttpCookie.matches_url?/2","doc":"Checks if the cookie matches the provided request url.\n\nThe check is done as specified in [RFC 6265](https://datatracker.ietf.org/doc/html/rfc6265#section-5.4).","ref":"HttpCookie.html#matches_url?/2"},{"type":"type","title":"HttpCookie.t/0","doc":"","ref":"HttpCookie.html#t:t/0"},{"type":"function","title":"HttpCookie.to_header_value/1","doc":"Formats the cookie for sending in a \"Cookie\" header.","ref":"HttpCookie.html#to_header_value/1"},{"type":"function","title":"HttpCookie.update_last_access_time/2","doc":"Updates the cookie last access time.\n\nUses the current time if no time is provided.","ref":"HttpCookie.html#update_last_access_time/2"},{"type":"module","title":"HttpCookie.Jar","doc":"HTTP Cookie Jar\n\nHandles storing cookies from response headers, preparing cookie headers for requests, etc.\n\nImplemented according to [RFC6265](https://datatracker.ietf.org/doc/html/rfc6265)","ref":"HttpCookie.Jar.html"},{"type":"function","title":"HttpCookie.Jar.clear_expired_cookies/2","doc":"Removes cookies which expired before the provided time from the jar.\n\nUses the current time if no time is provided.","ref":"HttpCookie.Jar.html#clear_expired_cookies/2"},{"type":"function","title":"HttpCookie.Jar.clear_session_cookies/1","doc":"Removes session cookies from the jar.\n\nCookies which don't have an explicit expiry time set are considered session cookies and they expire when a user session ends.","ref":"HttpCookie.Jar.html#clear_session_cookies/1"},{"type":"function","title":"HttpCookie.Jar.get_cookie_header_value/2","doc":"Formats the cookie for sending in a request header for the provided URL.","ref":"HttpCookie.Jar.html#get_cookie_header_value/2"},{"type":"function","title":"HttpCookie.Jar.get_matching_cookies/2","doc":"Gets all the cookies in the store which match the given request URL.","ref":"HttpCookie.Jar.html#get_matching_cookies/2"},{"type":"function","title":"HttpCookie.Jar.new/1","doc":"Creates a new empty cookie jar.","ref":"HttpCookie.Jar.html#new/1"},{"type":"function","title":"Options - HttpCookie.Jar.new/1","doc":"- `:max_cookies` - maximum number of cookies stored, positive integer or :infinity, default: 5_000\n- `:max_cookies_per_domain` - maximum number of cookies stored per domain, positive integer or :infinity, default: 100\n- `:cookie_opts` - options passed to HttpCookie.from_cookie_string/3","ref":"HttpCookie.Jar.html#new/1-options"},{"type":"function","title":"HttpCookie.Jar.put_cookie/3","doc":"Stores the provided cookie in the jar.","ref":"HttpCookie.Jar.html#put_cookie/3"},{"type":"function","title":"HttpCookie.Jar.put_cookies/2","doc":"Stores the provided cookies in the jar.","ref":"HttpCookie.Jar.html#put_cookies/2"},{"type":"function","title":"HttpCookie.Jar.put_cookies_from_headers/3","doc":"Processes the response header list for the given request URL.\nParses set-cookie/set-cookie2 headers and stores valid cookies.","ref":"HttpCookie.Jar.html#put_cookies_from_headers/3"},{"type":"type","title":"HttpCookie.Jar.t/0","doc":"","ref":"HttpCookie.Jar.html#t:t/0"},{"type":"module","title":"HttpCookie.ReqPlugin","doc":"Automatically manages cookies using http_cookie.","ref":"HttpCookie.ReqPlugin.html"},{"type":"function","title":"HttpCookie.ReqPlugin.attach/2","doc":"Attaches the plugin to the request pipeline.","ref":"HttpCookie.ReqPlugin.html#attach/2"},{"type":"function","title":"Request Options - HttpCookie.ReqPlugin.attach/2","doc":"* `:cookie_jar` - HttpCookie.Jar struct to use, defaults to `nil`","ref":"HttpCookie.ReqPlugin.html#attach/2-request-options"},{"type":"extras","title":"HttpCookie","doc":"# HttpCookie\n\n[![CI](https://github.com/reisub/http_cookie/actions/workflows/ci.yml/badge.svg)](https://github.com/reisub/http_cookie/actions/workflows/ci.yml)\n[![License](https://img.shields.io/hexpm/l/http_cookie.svg)](https://github.com/reisub/http_cookie/blob/main/LICENSE)\n[![Version](https://img.shields.io/hexpm/v/http_cookie.svg)](https://hex.pm/packages/http_cookie)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/http_cookie)\n\n[RFC6265](https://datatracker.ietf.org/doc/html/rfc6265)-compliant HTTP Cookie implementation for Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - HttpCookie","doc":"The package can be installed by adding `http_cookie` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:http_cookie, \"~> 0.7.0\"},\n    # not needed if the public suffix check is disabled,\n    # but it's highly recommended leaving it enabled\n    {:public_suffix, github: \"axelson/publicsuffix-elixir\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HttpCookie","doc":"```elixir\nurl = URI.parse(\"https://example.com\")\n\n# create a cookie jar\njar = HttpCookie.Jar.new()\n\n# when a response is received, save any cookies that might have been returned\nreceived_headers = [{\"Set-Cookie\", \"foo=bar\"}]\njar = Jar.put_cookies_from_headers(jar, url, received_headers)\n\n# before making requests, prepare the cookie header\n{:ok, cookie_header_value, jar} = Jar.get_cookie_header_value(jar, url)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Usage with `Req` - HttpCookie","doc":"HttpCookie can be used with [Req](https://github.com/wojtekmach/req) to automatically set and parse cookies in HTTP requests:\n\n```elixir\nempty_jar = HttpCookie.Jar.new()\n\nreq =\n  Req.new(base_url: \"https://example.com\", plug: plug)\n  |> HttpCookie.ReqPlugin.attach()\n\n%{private: %{cookie_jar: updated_jar}} = Req.get!(req, url: \"/one\", cookie_jar: empty_jar)\n%{private: %{cookie_jar: updated_jar}} = Req.get!(req, url: \"/two\", cookie_jar: updated_jar)\n```","ref":"readme.html#usage-with-req"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.7.0] - 2025-02-17","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- `:max_cookies` and `:max_cookies_per_domain` options for `HttpCookie.Jar`\n- `HttpCookie.ReqPlugin` for easy integration with Req","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Updating last access time\n\n## [0.6.0] - 2024-01-23","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- `HttpCookie.Jar` with basic functionality for a cookie jar\n- Comprehensive IETF test suite\n\n## [0.5.1] - 2024-01-20","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- More typespecs","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `nimble_parsec` is now a dev-only dependency\n\n## [0.5.0] - 2024-01-16","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release with core functionality: parsing Set-Cookie headers, URL matching logic","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}